## Command elf-info ##

`elf-info` (alias `elf`) provides some basic information on the currently
loaded ELF binary:

```
gef➤  elf
Magic                 : 7f 45 4c 46
Class                 : 0x2 - 64-bit
Endianness            : 0x1 - Little-Endian
Version               : 0x1
OS ABI                : 0x0 - System V
ABI Version           : 0x0
Type                  : 0x2 - Executable
Machine               : 0x3e - x86-64
Program Header Table  : 0x0000000000000040
Section Header Table  : 0x0000000000000c98
Header Table          : 0x0000000000000040
ELF Version           : 0x1
Header size           : 0 (0x0)
Entry point           : 0x0000000000400460
```
